using Avalonia.Controls;
using Avalonia.Interactivity;
using System;
using System.Linq;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using MsBox.Avalonia;
using MsBox.Avalonia.Enums;
using System.Collections.Generic;
using task01.Context;

namespace task01
{
    public partial class AddWindow : Window
    {
        

        public AddWindow(List<Department> departments, List<Profession> proffesinons)
        {
            InitializeComponent();
            

            DepartmentComboBox.ItemsSource = departments;
            ProfessionComboBox.ItemsSource = proffesinons;
        }

        private async void SaveButton_Click(object sender, RoutedEventArgs e)
        {
            var errors = ValidateInput();
            if (errors.Any())
            {
                await ShowError(string.Join(Environment.NewLine, errors));
                return;
            }

            var newEmployee = new Employee
            {
                Name = NameTextBox.Text,
                Phone = PhoneTextBox.Text,
                Surname = SurnameTextBox.Text,
                Patronymic = PatronymicTextBox.Text,
                Birthday = DateOnly.FromDateTime(BirthdayDatePicker.SelectedDate?.DateTime ?? DateTime.Now),
                Departmentid = (DepartmentComboBox.SelectedItem as Department).Id,
                Proffesionid = (ProfessionComboBox.SelectedItem as Profession).Id,
                Email = EmailTextBox.Text,
                Office = new Office { Title = OfficeTextBox.Text }
            };

            using var context = new User11Context();
            context.Employees.Add(newEmployee);
            context.SaveChanges();

            var mainWindow = new MainWindow();
            mainWindow.Show();
            Close();
        }

        private async void BackButton_Click(object sender, RoutedEventArgs e)
        {
            var mainWindow = new MainWindow();
            mainWindow.Show();
            Close();
        }

        private List<string> ValidateInput()
        {
            var errors = new List<string>();

            if (string.IsNullOrWhiteSpace(NameTextBox.Text))
            {
                errors.Add("   .");
            }

            if (string.IsNullOrWhiteSpace(PhoneTextBox.Text) || !Regex.IsMatch(PhoneTextBox.Text, @"^[+\d()# -]{1,20}$"))
            {
                errors.Add("        \"+(), -, #\" ( 20 ).");
            }

            if (!BirthdayDatePicker.SelectedDate.HasValue)
            {
                errors.Add("    .");
            }

            if (DepartmentComboBox.SelectedItem == null)
            {
                errors.Add("    .");
            }

            if (ProfessionComboBox.SelectedItem == null)
            {
                errors.Add("   .");
            }

            if (string.IsNullOrWhiteSpace(EmailTextBox.Text) || !Regex.IsMatch(EmailTextBox.Text, @"^[^@\s]+@[^@\s]+\.[^@\s]+$"))
            {
                errors.Add("          x@x.x.");
            }

            if (string.IsNullOrWhiteSpace(OfficeTextBox.Text) || OfficeTextBox.Text.Length > 10)
            {
                errors.Add("    ( 10 ).");
            }

            return errors;
        }

        private async Task ShowError(string message)
        {
            var box = MessageBoxManager
                .GetMessageBoxStandard("", message, ButtonEnum.Ok);
            await box.ShowAsync();
        }
    }
}
