using Avalonia;
using Avalonia.Controls;
using Avalonia.Controls.Shapes;
using Avalonia.Interactivity;
using Avalonia.Markup.Xaml;
using Avalonia.Media;
using Microsoft.EntityFrameworkCore;
using MsBox.Avalonia.Enums;
using MsBox.Avalonia;
using System;
using System.Collections.Generic;
using System.Linq;
using task01.Context;

namespace task01
{
    public partial class MainWindow : Window
    {
        private List<Department> _departments;
        private List<Employee> _employees;
        private List<Profession> _professions;

        public MainWindow()
        {
            InitializeComponent();
            LoadData();
        }

        private void LoadData()
        {
            using var context = new User11Context();
            _departments = context.Departments.ToList();
            _employees = context.Employees.Include(e => e.Office).Include(e => e.Proffesion).ToList();
            _professions = context.Professions.ToList();

            DepartmentsListBox.ItemsSource = _departments;
        }

        private void DepartmentsListBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (DepartmentsListBox.SelectedItem is Department selectedDepartment)
            {
                LoadEmployeeDepartment(selectedDepartment);
            }
        }

        private void LoadEmployeeDepartment(Department department)
        {
            if (department == null) return;

            var departmentEmployees = _employees.Where(e => e.Departmentid == department.Id).ToList();
            EmployeesListBox.ItemsSource = departmentEmployees;
        }

        private void EmployeesListBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (EmployeesListBox.SelectedItem is Employee selectedEmployee)
            {
                var showWindow = new ShowWindow(selectedEmployee, _departments, _professions);
                showWindow.Show();
                LoadData();
                Close();
            }

        }

        private void AddButton_Click(object sender, RoutedEventArgs e)
        {
            var AddWindow = new AddWindow(_departments, _professions);
            AddWindow.Show();
            Close();
        }
    }
}